@@ -3,14 +3,13 @@ This app doesn't have any models, per se, but the following ``R`` class is a
 lightweight wrapper around Redis.
 
 """
-from collections import OrderedDict
-from datetime import datetime, timedelta
-
 import redis
 
-from django.conf import settings
+from collections import OrderedDict
+from datetime import datetime, timedelta
 from django.template.defaultfilters import slugify
 
+from .settings import app_settings, GRANULARITIES, METRIC_KEY_PATTERNS
 from .templatetags import redis_metrics_filters as template_tags
 
 
@@ -43,28 +42,18 @@ class R(object):
         self._metric_slugs_key = kwargs.get('metric_slugs_key', 'metric-slugs')
         self._gauge_slugs_key = kwargs.get('gauge_slugs_key', 'gauge-slugs')
 
-        self.host = kwargs.pop(
-            'host',
-            getattr(settings, 'REDIS_METRICS_HOST', 'localhost'))
-
-        self.port = kwargs.pop(
-            'port',
-            int(getattr(settings, 'REDIS_METRICS_PORT', 6379)))
-
-        self.db = kwargs.pop(
-            'db',
-            int(getattr(settings, 'REDIS_METRICS_DB', 0)))
-
-        self.password = kwargs.pop(
-            'password', getattr(settings, 'REDIS_METRICS_PASSWORD', None))
-
+        self.host = kwargs.pop('host', app_settings.REDIS_METRICS_HOST)
+        self.port = kwargs.pop('port', app_settings.REDIS_METRICS_PORT)
+        self.db = kwargs.pop('db', app_settings.REDIS_METRICS_DB)
+        self.password = kwargs.pop('password', app_settings.REDIS_METRICS_PASSWORD)
         self.socket_timeout = kwargs.pop(
             'socket_timeout',
-            getattr(settings, 'REDIS_METRICS_SOCKET_TIMEOUT', None))
-
+            app_settings.REDIS_METRICS_SOCKET_TIMEOUT
+        )
         self.connection_pool = kwargs.pop(
             'connection_pool',
-            getattr(settings, 'REDIS_METRICS_SOCKET_CONNECTION_POOL', None))
+            app_settings.REDIS_METRICS_SOCKET_CONNECTION_POOL
+        )
 
         # Create the connection to Redis
         self.r = redis.StrictRedis(
@@ -159,6 +148,30 @@ class R(object):
         # Store all category names in a Redis set, for easy retrieval
         self.r.sadd(self._categories_key, category)
 
+    def _granularities(self):
+        """Returns a generator of all possible granularities based on the
+        REDIS_METRICS_MIN_GRANULARITY and REDIS_METRICS_MAX_GRANULARITY settings.
+        """
+        keep = False
+        for g in GRANULARITIES:
+            if g == app_settings.REDIS_METRICS_MIN_GRANULARITY and not keep:
+                keep = True
+            elif g == app_settings.REDIS_METRICS_MAX_GRANULARITY and keep:
+                keep = False
+                yield g
+            if keep:
+                yield g
+
+    def _build_key_patterns(self, slug, date):
+        """Builds an OrderedDict of metric keys and patterns for the given slug
+        and date."""
+        # we want to keep the order, from smallest to largest granularity
+        patts = OrderedDict()
+        for g in self._granularities():
+            date_string = date.strftime(METRIC_KEY_PATTERNS[g]["date_format"])
+            patts[g] = METRIC_KEY_PATTERNS[g]["key"].format(slug, date_string)
+        return patts
+
     def _build_keys(self, slug, date=None, granularity='all'):
         """Builds redis keys used to store metrics.
 
@@ -175,22 +188,8 @@ class R(object):
         slug = slugify(slug)  # Ensure slugs have a consistent format
         if date is None:
             date = datetime.utcnow()
-
-        # we want to keep the order, here, from smallest to largest granularity:
-        # seconds, minutes, hourly, daily, weekly, monthly, yearly
-        patts = OrderedDict()
-        patts["seconds"] = "m:{0}:s:{1}".format(slug, date.strftime("%Y-%m-%d-%H-%M-%S"))
-        patts["minutes"] = "m:{0}:i:{1}".format(slug, date.strftime("%Y-%m-%d-%H-%M"))
-        patts["hourly"] = "m:{0}:h:{1}".format(slug, date.strftime("%Y-%m-%d-%H"))
-        patts["daily"] = "m:{0}:{1}".format(slug, date.strftime("%Y-%m-%d"))
-        patts["weekly"] = "m:{0}:w:{1}".format(slug, date.strftime("%Y-%U"))
-        patts["monthly"] = "m:{0}:m:{1}".format(slug, date.strftime("%Y-%m"))
-        patts["yearly"] = "m:{0}:y:{1}".format(slug, date.strftime("%Y"))
-
-        if granularity == 'all':
-            return patts.values()
-        else:
-            return [patts[granularity]]
+        patts = self._build_key_patterns(slug, date)
+        return patts.values() if granularity == "all" else [patts[granularity]]
 
     def metric_slugs(self):
         """Return a set of metric slugs (i.e. those used to create Redis keys)
@@ -304,34 +303,19 @@ class R(object):
             m:<slug>:y:<yyyy>                # Year
 
         """
-        keys = self._build_keys(slug)
-        sec_key, min_key, hour_key, day_key, week_key, month_key, year_key = keys
-
         # Add the slug to the set of metric slugs
         self.r.sadd(self._metric_slugs_key, slug)
 
-        # Increment keys. NOTE: current redis-py (2.7.2) doesn't include an
-        # incrby method; .incr accepts a second ``amount`` parameter.
-        self.r.incr(sec_key, num)
-        self.r.incr(min_key, num)
-        self.r.incr(hour_key, num)
-        self.r.incr(day_key, num)
-        self.r.incr(week_key, num)
-        self.r.incr(month_key, num)
-        self.r.incr(year_key, num)
-
         if category:
             self._categorize(slug, category)
 
-        # Expire the Metric in ``expire`` seconds
-        if expire:
-            self.r.expire(sec_key, expire)
-            self.r.expire(min_key, expire)
-            self.r.expire(hour_key, expire)
-            self.r.expire(day_key, expire)
-            self.r.expire(week_key, expire)
-            self.r.expire(month_key, expire)
-            self.r.expire(year_key, expire)
+        # Increment keys. NOTE: current redis-py (2.7.2) doesn't include an
+        # incrby method; .incr accepts a second ``amount`` parameter.
+        keys = self._build_keys(slug)
+        for key in keys:
+            self.r.incr(key, num)
+            if expire:
+                self.r.expire(key, expire)
 
     def get_metric(self, slug):
         """Get the current values for a metric.
@@ -340,17 +324,12 @@ class R(object):
         minutes, hours, day, week, month, and year.
 
         """
+        results = OrderedDict()
+        granularities = self._granularities()
         keys = self._build_keys(slug)
-        sec_key, min_key, hour_key, day_key, week_key, month_key, year_key = keys
-        return {
-            'seconds': self.r.get(sec_key),
-            'minutes': self.r.get(min_key),
-            'hours': self.r.get(hour_key),
-            'day': self.r.get(day_key),
-            'week': self.r.get(week_key),
-            'month': self.r.get(month_key),
-            'year': self.r.get(year_key),
-        }
+        for granularity, key in zip(granularities, keys):
+            results[granularity] = self.r.get(key)
+        return results
 
     def get_metrics(self, slug_list):
         """Get the metrics for multiple slugs.
@@ -366,13 +345,18 @@ class R(object):
             )
 
         """
+        # meh. I should have been consistent here, but I'm lazy, so support these
+        # value names instead of granularity names, but respect the min/max
+        # granularity settings.
+        keys = ['seconds', 'minutes', 'hours', 'day', 'week', 'month', 'year']
+        key_mapping = {gran: key for gran, key in zip(GRANULARITIES, keys)}
+        keys = [key_mapping[gran] for gran in self._granularities()]
+
         results = []
         for slug in slug_list:
-            keys = ['seconds', 'minutes', 'hours', 'day', 'week', 'month', 'year']
             metrics = self.r.mget(*self._build_keys(slug))
             if any(metrics):  # Only if we have data.
-                d = dict(zip(keys, metrics))
-                results.append((slug, d))
+                results.append((slug, dict(zip(keys, metrics))))
         return results
 
     def get_category_metrics(self, category):
