@@ -4,6 +4,7 @@
 from datetime import datetime, timedelta
 
 from django.test import TestCase
+from django.test.utils import override_settings
 from mock import patch
 from redis_metrics.templatetags import redis_metric_tags as taglib
 from redis_metrics.templatetags.redis_metrics_filters import (
@@ -11,6 +12,15 @@ from redis_metrics.templatetags.redis_metrics_filters import (
 )
 
 
+
+@override_settings(REDIS_METRICS_HOST='localhost')
+@override_settings(REDIS_METRICS_PORT=6379)
+@override_settings(REDIS_METRICS_DB=0)
+@override_settings(REDIS_METRICS_PASSWORD=None)
+@override_settings(REDIS_METRICS_SOCKET_TIMEOUT=None)
+@override_settings(REDIS_METRICS_SOCKET_CONNECTION_POOL=None)
+@override_settings(REDIS_METRICS_MIN_GRANULARITY='seconds')
+@override_settings(REDIS_METRICS_MAX_GRANULARITY='yearly')
 class TestTemplateTags(TestCase):
     """Verify that template tags return the expected results."""
     maxDiff = None
@@ -95,7 +105,7 @@ class TestTemplateTags(TestCase):
 
     def test_gauge(self):
         """Tests the result of the gauge template tag."""
-        with patch("redis_metrics.templatetags.redis_metric_tags.R") as mock_r:
+        with patch("redis_metrics.templatetags.redis_metric_tags.get_r") as mock_r:
             inst = mock_r.return_value
             inst.get_gauge.return_value = 100
 
@@ -115,7 +125,7 @@ class TestTemplateTags(TestCase):
 
     def test_gauge_when_overloaded(self):
         """Tests the result of a gauge whose current value > the maximum"""
-        with patch("redis_metrics.templatetags.redis_metric_tags.R") as mock_r:
+        with patch("redis_metrics.templatetags.redis_metric_tags.get_r") as mock_r:
             inst = mock_r.return_value
             inst.get_gauge.return_value = 500
 
@@ -134,7 +144,7 @@ class TestTemplateTags(TestCase):
             inst.get_gauge.assert_called_once_with("test-slug")
 
     def test_metric_list(self):
-        with patch("redis_metrics.templatetags.redis_metric_tags.R") as mock_r:
+        with patch("redis_metrics.templatetags.redis_metric_tags.get_r") as mock_r:
             inst = mock_r.return_value
             inst.metric_slugs_by_category.return_value = "RESULT"
 
@@ -147,12 +157,14 @@ class TestTemplateTags(TestCase):
             inst.metric_slugs_by_category.assert_called_once_with()
 
     def test_metric_detail(self):
-        with patch("redis_metrics.templatetags.redis_metric_tags.R") as mock_r:
+        with patch("redis_metrics.templatetags.redis_metric_tags.get_r") as mock_r:
             inst = mock_r.return_value
             inst.get_metric.return_value = "RESULT"
+            inst._granularities.return_value = ['daily', 'weekly']
 
             result = taglib.metric_detail('test')
             expected_result = {
+                'granularities': ['daily', 'weekly'],
                 'slug': 'test',
                 'metrics': "RESULT",
                 'with_data_table': False,
@@ -162,7 +174,7 @@ class TestTemplateTags(TestCase):
             inst.get_metric.assert_called_once_with('test')
 
     def test_metric_history(self):
-        with patch("redis_metrics.templatetags.redis_metric_tags.R") as mock_r:
+        with patch("redis_metrics.templatetags.redis_metric_tags.get_r") as mock_r:
             history = [("m:test:2000-01-01", 42)]
             inst = mock_r.return_value
             inst.get_metric_history.return_value = history
@@ -184,7 +196,7 @@ class TestTemplateTags(TestCase):
             )
 
     def test_metric_history_with_date(self):
-        with patch("redis_metrics.templatetags.redis_metric_tags.R") as mock_r:
+        with patch("redis_metrics.templatetags.redis_metric_tags.get_r") as mock_r:
             history = [("m:test:2000-01-01", 42)]
             inst = mock_r.return_value
             inst.get_metric_history.return_value = history
@@ -232,7 +244,7 @@ class TestTemplateTags(TestCase):
             )
 
     def test_aggregate_detail(self):
-        with patch("redis_metrics.templatetags.redis_metric_tags.R") as mock_r:
+        with patch("redis_metrics.templatetags.redis_metric_tags.get_r") as mock_r:
             slugs = ['a1', 'a2']
             inst = mock_r.return_value
             inst.get_metrics.return_value = 'RESULTS'
@@ -249,7 +261,7 @@ class TestTemplateTags(TestCase):
             inst.get_metrics.assert_called_once_with(slugs)
 
     def test_aggregate_history(self):
-        with patch("redis_metrics.templatetags.redis_metric_tags.R") as mock_r:
+        with patch("redis_metrics.templatetags.redis_metric_tags.get_r") as mock_r:
             history = {
                 'periods': ['2000-01-01', '2000-01-02', '2000-01-03'],
                 'data': [
@@ -286,7 +298,7 @@ class TestTemplateTags(TestCase):
             )
 
     def test_aggregate_history_with_date(self):
-        with patch("redis_metrics.templatetags.redis_metric_tags.R") as mock_r:
+        with patch("redis_metrics.templatetags.redis_metric_tags.get_r") as mock_r:
             history = {
                 'periods': ['2000-01-01', '2000-01-02', '2000-01-03'],
                 'data': [
@@ -330,7 +342,7 @@ class TestTemplateTags(TestCase):
             self.assertEqual(result, expected_result)
 
     def test_aggregate_history_with_tabular_data(self):
-        with patch("redis_metrics.templatetags.redis_metric_tags.R") as mock_r:
+        with patch("redis_metrics.templatetags.redis_metric_tags.get_r") as mock_r:
             history = {
                 'periods': ['2000-01-01', '2000-01-02', '2000-01-03'],
                 'data': [
