@@ -7,20 +7,32 @@ Replace this with more appropriate tests for your application.
 from datetime import datetime
 from mock import call, patch
 
-try:  # pragma: no cover
-    # Django 1.5
-    from django.contrib.auth import get_user_model  # pragma: no cover
-    User = get_user_model()  # pragma: no cover
-except ImportError:  # pragma: no cover
-    # Fallback for Django 1.4 (or lower)
-    from django.contrib.auth.models import User  # pragma: no cover
 from django.core.urlresolvers import reverse
 from django.test import TestCase, Client
+from django.test.utils import override_settings
 
 
+@override_settings(REDIS_METRICS_HOST='localhost')
+@override_settings(REDIS_METRICS_PORT=6379)
+@override_settings(REDIS_METRICS_DB=0)
+@override_settings(REDIS_METRICS_PASSWORD=None)
+@override_settings(REDIS_METRICS_SOCKET_TIMEOUT=None)
+@override_settings(REDIS_METRICS_SOCKET_CONNECTION_POOL=None)
+@override_settings(REDIS_METRICS_MIN_GRANULARITY='seconds')
+@override_settings(REDIS_METRICS_MAX_GRANULARITY='yearly')
 class TestViews(TestCase):
     url = 'redis_metrics.urls'
 
+    def _get_user_model(self):
+        try:  # pragma: no cover
+            # Django >= 1.5
+            from django.contrib.auth import get_user_model  # pragma: no cover
+            User = get_user_model()  # pragma: no cover
+        except ImportError:  # pragma: no cover
+            # Fallback for Django 1.4 (or lower)
+            from django.contrib.auth.models import User  # pragma: no cover
+        return User
+
     def setUp(self):
         # Patch the connection to redis, but keep a reference to the
         # created StrictRedis instance, so we can make assertions about how
@@ -29,6 +41,7 @@ class TestViews(TestCase):
         mock_StrictRedis = self.redis_patcher.start()
         self.redis = mock_StrictRedis.return_value
 
+        User = self._get_user_model()
         self.user = User.objects.create_superuser(
             username="redis_metrics_test_user",
             email="redis_metrics_test_user@example.com",
@@ -57,7 +70,7 @@ class TestViews(TestCase):
     def test_gauges_view(self):
         """Test the ``GaugesView``."""
         url = reverse('redis_metrics_gauges')
-        with patch('redis_metrics.views.R') as mock_r:
+        with patch('redis_metrics.views.get_r') as mock_r:
             # Set appropriate return values for methods that'll get called
             # in the MetricsListView.
             r = mock_r.return_value  # Get an instance of our Mocked R class
@@ -78,7 +91,7 @@ class TestViews(TestCase):
     def test_metrics_list(self):
         """Test the ``MetricsListView``."""
         url = reverse('redis_metrics_list')
-        with patch('redis_metrics.views.R') as mock_r:
+        with patch('redis_metrics.views.get_r') as mock_r:
             # Set appropriate return values for methods that'll get called
             # in the MetricsListView.
             r = mock_r.return_value  # Get an instance of our Mocked R class
@@ -100,26 +113,36 @@ class TestViews(TestCase):
             ])
 
     def test_metric_detail(self):
-        slug = u'test-metric'
-        url = reverse('redis_metric_detail', args=[slug])
+        with patch('redis_metrics.views.get_r') as mock_get_r:
+            inst = mock_get_r.return_value
+            inst._granularities.return_value = ['daily', 'weekly']
 
-        # Do the Request & test results
-        resp = self.client.get(url)
-        self.assertEqual(resp.status_code, 200)
-        self.assertEqual(resp.context_data['slug'], slug)
+            slug = u'test-metric'
+            url = reverse('redis_metric_detail', args=[slug])
+
+            # Do the Request & test results
+            resp = self.client.get(url)
+            self.assertEqual(resp.status_code, 200)
+            self.assertEqual(resp.context_data['slug'], slug)
+            self.assertEqual(resp.context_data['granularities'], ['daily', 'weekly'])
 
     def test_metric_history(self):
-        slug = u'test-metric'
-        granularity = u'daily'
-        url = reverse('redis_metric_history', args=[slug, granularity])
+        with patch('redis_metrics.views.get_r') as mock_get_r:
+            inst = mock_get_r.return_value
+            inst._granularities.return_value = ['daily', 'weekly']
 
-        # Do the Request & test results
-        resp = self.client.get(url)
-        self.assertEqual(resp.status_code, 200)
-        context = resp.context_data
-        self.assertEqual(context['slug'], slug)
-        self.assertEqual(context['since'], None)
-        self.assertEqual(context['granularity'], granularity)
+            slug = u'test-metric'
+            granularity = u'daily'
+            url = reverse('redis_metric_history', args=[slug, granularity])
+
+            # Do the Request & test results
+            resp = self.client.get(url)
+            self.assertEqual(resp.status_code, 200)
+            context = resp.context_data
+            self.assertEqual(context['slug'], slug)
+            self.assertEqual(context['since'], None)
+            self.assertEqual(context['granularity'], granularity)
+            self.assertEqual(context['granularities'], ['daily', 'weekly'])
 
     def test_metric_history_since(self):
         """Tests the ``MetricHistoryView`` when there's a ``since`` variable"""
@@ -164,7 +187,7 @@ class TestViews(TestCase):
         correct context info (i.e. a form)."""
         url = reverse('redis_metric_aggregate')
         self.assertUnauthedRequestRedirects(url)
-        with patch('redis_metrics.views.R'):
+        with patch('redis_metrics.views.get_r'):
             resp = self.client.get(url)
             self.assertEqual(resp.status_code, 200)
             self.assertIn('form', resp.context_data)
@@ -173,7 +196,7 @@ class TestViews(TestCase):
         """Verifies that POST requests to the ``AggregateFormView`` work as
         expected."""
         url = reverse('redis_metric_aggregate')
-        with patch('redis_metrics.views.R'):
+        with patch('redis_metrics.views.get_r'):
             with patch('redis_metrics.forms.R') as mock_r:
                 # Set up a return value for ``R.metric_slugs``, which is used
                 # in the ``AggregateMetricForm``
@@ -196,34 +219,45 @@ class TestViews(TestCase):
 
     def test_aggregate_detail_view(self):
         """Tests ``views.AggregateDetailView``."""
+        with patch('redis_metrics.views.get_r') as mock_get_r:
+            inst = mock_get_r.return_value
+            inst._granularities.return_value = ['daily', 'weekly']
 
-        slug_set = set(['foo', 'bar', 'test-metric', 'yippitty-poo-bah'])
-        slugs = '+'.join(slug_set)
-        url = reverse('redis_metric_aggregate_detail', args=[slugs])
+            slug_set = set(['foo', 'bar', 'test-metric', 'yippitty-poo-bah'])
+            slugs = '+'.join(slug_set)
+            url = reverse('redis_metric_aggregate_detail', args=[slugs])
 
-        # Do the Request & test results
-        resp = self.client.get(url)
-        self.assertEqual(resp.status_code, 200)
-        self.assertIn('slugs', resp.context_data)
-        self.assertEqual(resp.context_data['slugs'], slug_set)
+            # Do the Request & test results
+            resp = self.client.get(url)
+            self.assertEqual(resp.status_code, 200)
+            self.assertIn('slugs', resp.context_data)
+            self.assertIn('granularities', resp.context_data)
+            self.assertEqual(resp.context_data['slugs'], slug_set)
+            self.assertEqual(resp.context_data['granularities'], ['daily', 'weekly'])
 
     def _test_aggregate_history_view(self, slugs, granularity):
         """Tests ``views.AggregateHistoryView`` with the given slugs,
         granularity, without a specified date verifying the values are
         correctly passed to the template."""
-        slug_set = set(slugs)
-        url = reverse('redis_metric_aggregate_history',
-                      args=['+'.join(slugs), granularity])
+        with patch('redis_metrics.views.get_r') as mock_get_r:
+            inst = mock_get_r.return_value
+            inst._granularities.return_value = ['daily', 'weekly']
 
-        # Do the Request & test results
-        resp = self.client.get(url)
-        self.assertEqual(resp.status_code, 200)
-        self.assertIn('slugs', resp.context_data)
-        self.assertIn('granularity', resp.context_data)
-        self.assertIn('since', resp.context_data)
-        self.assertEqual(resp.context_data['slugs'], slug_set)
-        self.assertEqual(resp.context_data['granularity'], granularity)
-        self.assertIsNone(resp.context_data['since'])
+            slug_set = set(slugs)
+            url = reverse('redis_metric_aggregate_history',
+                          args=['+'.join(slugs), granularity])
+
+            # Do the Request & test results
+            resp = self.client.get(url)
+            self.assertEqual(resp.status_code, 200)
+            self.assertIn('slugs', resp.context_data)
+            self.assertIn('granularity', resp.context_data)
+            self.assertIn('since', resp.context_data)
+            self.assertIn('granularities', resp.context_data)
+            self.assertEqual(resp.context_data['slugs'], slug_set)
+            self.assertEqual(resp.context_data['granularity'], granularity)
+            self.assertEqual(resp.context_data['granularities'], ['daily', 'weekly'])
+            self.assertIsNone(resp.context_data['since'])
 
     def test_aggregate_history_view_hourly(self):
         self._test_aggregate_history_view(['foo', 'bar'], 'hourly')
